#!/bin/sh
###################################################################################
# MntShare.sh V0.3, written by Eagleeye/DFT
# For updates look at www.jan-blumenthal.de
###################################################################################
# Args:$1 Name of Computer
#      $2 SMB username
#      $3 Password
#      $4 Path of mountpoint with slash ("/mnt/test/" not "/mnt/test")
#      $5 Local user (default: current user)
#      $6 File mask
# returnvalue: 0=done(true), 1=something was wrong(false)
###################################################################################
_VERSION=0.3
_PARAMETERS=$#

# check if enough parameters are given
if test $_PARAMETERS -ge 3
then
  _COMPUTER=$1
  _SMBUSERNAME=$2
  _PASSWORD=$3
  _MOUNTPOINT=$4
  _USERNAMEID=`id -u`
  _USERGROUPID=`id -g`
  _MASK=0755


  # set correct mountpoint. If no mountpoint specified the lowercase computername
  # will be added to /mnt/
  if test $_PARAMETERS -gt 3
  then
    _MOUNTPOINT=$4
  else
    _MOUNTPOINT=/mnt/`echo $1 | tr [:upper:] [:lower:]`/
  fi


  # set correct local user
  if test $_PARAMETERS -gt 4
  then
    _USERNAMEID=`id -u $5`
    _USERGROUPID=`id -g $5`
  fi


  # set correct usermask
  if test $_PARAMETERS -gt 5
  then
    _MASK=$6
  fi


  # Needed to mount drives via mount later
  export _COMPUTER
  export _SMBUSERNAME
  export _PASSWORD
  export _MOUNTPOINT
  export _USERNAMEID
  export _USERGROUPID
  export _MASK


  # start mounting
  echo "Mounting $_COMPUTER shared drives as user: $_SMBUSERNAME in: $_MOUNTPOINT" 
  mkdir $_MOUNTPOINT 2>/dev/null
  cd $_MOUNTPOINT

  # if mountpoint exists then the script can be continue
  if test -d $_MOUNTPOINT
  then
    # umount old mounted drives
    umount * 2>/dev/null
    rmdir * 2>/dev/null


  # 1. get all shared drives of requested computer
  # 2. grep all discdrives
  # 3. grep all non hided discdrives
  # 4. remove all non interesting information
  # 5. remove all spaces from drivenames
  # 6. make all letters lowercase
  # 7. Perl-Script to do everything with each line (mount the drives)
    smbclient -L //$_COMPUTER -U $_SMBUSERNAME%$_PASSWORD -N | grep Disk | grep -v .*$.* | cut -b 2-16 | tr -d \ | tr [A-Z] [a-z]|perl -n -e 's/^(.+)\s*$/$1/; mkdir($_,0777); system "mount -t smbfs -o username=$ENV{_SMBUSERNAME},password=$ENV{_PASSWORD},uid=$ENV{_USERNAMEID},gid=$ENV{_USERGROUPID},fmask=$ENV{_MASK},dmask=$ENV{_MASK} //$ENV{_COMPUTER}/$_ $ENV{_MOUNTPOINT}$_ 2>/dev/null"'


    # umount unaccessable drives because may may crash without this
    for i in `ls`
    do
      if ! ls $i 1>/dev/NULL 2>/dev/NULL
      then
        umount $i
        rmdir $i
      fi
    done 

  exit 0

  fi
else
  # Parameters were given wrong
  echo "MNTShare.sh V$_VERSION"
  echo "Mount shared Windows drives. Written by Jan Blumenthal (www.jan-blumenthal.de)"
  echo "This script is under GNU public license and is distributed as is. No warrenty!"
  echo "You may use it on your own risk! Please make sure that you are logged in as"
  echo "root and you have installed samba already."
  echo "Usage:"
  echo "mntshare.sh <Computer> <SMBUsername> <Password> [Mountpoint] [Username] [UMask]"
  echo "Defaults: Mountpoint: /mnt/<Computer>"
  echo "          User:       \`whoami\` (normally root)"
  echo "          UMask:      0755"
  echo "Examples: (1) mntshare.sh OXYGEN jblumenthal secure /mnt/oxygen/ eagleeye 0755"
  echo "          (2) mntshare.sh MOVIES eagleeye secure"
  exit 1
fi





